<?php

namespace Drupal\gigwa\Form;

use Drupal\Component\Utility\UrlHelper;
use Drupal\Core\Config\Config;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * A simple form that displays a select box and submit button.
 *
 * This form will be be themed by the 'theming_example_select_form' theme
 * handler.
 */
class GigwaAdminForm extends FormBase {

  /**
   * @var \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * @param \Drupal\Core\Config\Config $config
   */
  public function __construct(Config $config) {
    $this->config = $config;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory')->getEditable('gigwa.settings')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'gigwa_admin_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // @todo: Choose title.
    // Gigwa URL.
    $form['gigwa_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Gigwa URL'),
      '#size' => 60,
      '#default_value' => $this->config->get('gigwa_url', ''),
    ];

    // Form save button.
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];

    return $form;
  }

  /**
   * Form element validation handler for #type 'url'.
   *
   * Note that #maxlength and #required is validated by _form_validate() already.
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $org_gigwa_url = $gigwa_url = $form_state->getValue('gigwa_url', '');
    if (('' !== $gigwa_url) && !preg_match('#^https?:#', $gigwa_url)) {
      $gigwa_url = 'https://' . ltrim($gigwa_url, '/');
    }
    if (('' !== $gigwa_url) && !UrlHelper::isValid($gigwa_url, TRUE)) {
      $form_state->setErrorByName(
        'gigwa_url',
        $this->t('The URL %url is not valid.', ['%url' => $org_gigwa_url,])
      );
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $gigwa_url = $form_state->getValue('gigwa_url', '');
    $this->config->set('gigwa_url', $gigwa_url);
    $this->config->save();
    $this->messenger()->addMessage($this->t('Gigwa settings have been updated.'));
  }
}
